-- total revamp for ver 1.31
-- no longer any need to pre-process data files as they are no longer converted to .plugindata files
-- all this file does is define the LoadDefaults() function which is then called by main.lua (passing the IconInfo and MapInfo tables by reference so that they can be updated)

-- iconInfo is in the form {StringResourceID, Height, Width, Image ResourceID/Path, Highlighted Image ResourceID/Path, filterOrder,default icon, default hover icon, default clicked icon}

-- mapInfo is in the form {Index,StringResourceID, ImageResourceID/Path, Width, Height, HFactor,HOffset,WFactor,WOffset,ParentMapID,MapType,Region,MaxNS,MinEW,MinNS,MaxEW,Tier,StringResourceID_DE,StringResourceID_FR,StringResourceID_RU,{northern boundary points},{western boundary points},{southern boundary points},{eastern boundary points}}
-- HFactor and HOffset are used in the conversion from map coordinates to pixels: X=Height*HFactor+HOffset will convert coordinate "Height" to pixel "X"
-- -- the excel spreadsheet "MoorMap Data.xls" contains the calculated values using two points, one at top left of map, the other at bottom right of map.
-- -- source columns: B=top left NS, C=top left world EW, D=top left pixel world X, E=top left pixel Y, F=bottom right NS, G=bottom right world EW, H=bottom right pixel world X, I=bottom right pixel Y
-- -- calculated columns: J=hFactor, M=hOffset, N=wFactor, Q=wOffset
-- ParentMapID is used to create the tree structure
-- MapTypeID - 0=Undefined, 1=Parchment (coordinates match world coordinates), 2=Interior/Underground (coordinates do NOT match world coordinates), 3=Interior/Underground subzone (hidden until parent is moused over in list and coordinates do not match world)
-- Region is the region code (from /loc) 0=Undefined/world map, 1=Eriador, 2=Rhovanion, 3=Gondor
-- Min&Max coordinates are the corners of the map
-- Tier is the zoom level of the map with "Middle Earth" being 1, "Eriador" and "Rhovanion" being 2, etc. this is used to determine the best map for adding annotations whose coordinates are included in more than one map
-- Borders are triplets representing horizontal or vertical line segments. The first value is the common coordinate, the second and third values are the starting and ending points for the line segment - so for a northern boundary, the first value is the north/south coordinate for a line starting at the east/west value of the second coordinate extending to the east/west value of the third coordinate
-- Note, StringResourceID_DE,StringResourceID_FR,StringResourceID_RU and Borders are no longer in use. The string resources were correctly incorporated into the .DAT files by Turbine (after being broken for about 2 years) and the Borders were never implemented as the algorithm for finding best match using tier and distance from center of map has worked well.

-- the client shows interior maps as 800x600 in a 1024x768 frame offset at 112,84 and then stretched to whatever current resolution is.

function LoadDefaults(tmpIconInfo,tmpMapInfo)
	local tmpIconInfo2={}
	tmpIconInfo2[1]={106,36,36,"MainBase.tga","MainBase_hover.tga","MainBase_icon.tga",1,"MainBase.tga","MainBase_hover.tga","MainBase_icon.tga"};
	tmpIconInfo2[2]={107,32,32,"Base.tga","Base_hover.tga","Base_icon.tga",2,"Base.tga","Base_hover.tga","Base_icon.tga"};
	tmpIconInfo2[3]={108,24,24,"Fort.tga","Fort_hover.tga","Fort_icon.tga",3,"Fort.tga","Fort_hover.tga","Fort_icon.tga"};
	tmpIconInfo2[4]={109,24,24,"Outpost.tga","Outpost_hover.tga","Outpost_icon.tga",4,"Outpost.tga","Outpost_hover.tga","Outpost_icon.tga"};
	tmpIconInfo2[5]={110,30,30,0x41005e5e,0x41005e60,0x41005e5f,7,0x41005e5e,0x41005e60,0x41005e5f}; -- poi
	tmpIconInfo2[6]={111,18,18,"Stockade.tga","Stockade_hover.tga","Stockade_icon.tga",5,"Stockade.tga","Stockade_hover.tga","Stockade_icon.tga"};
	tmpIconInfo2[7]={112,24,24,"Rez.tga","Rez_hover.tga","Rez_icon.tga",9,"Rez.tga","Rez_hover.tga","Rez_icon.tga"};
	tmpIconInfo2[8]={113,18,18,"CrudeMap.tga","CrudeMap_hover.tga","CrudeMap.tga",nil,"CrudeMap.tga","CrudeMap_hover.tga","CrudeMap.tga"};
	tmpIconInfo2[9]={114,18,18,"PoorMap.tga","PoorMap_hover.tga","PoorMap.tga",nil,"PoorMap.tga","PoorMap_hover.tga","PoorMap.tga"};
	tmpIconInfo2[10]={115,18,18,"GoodMap.tga","GoodMap_hover.tga","GoodMap.tga",6,"GoodMap.tga","GoodMap_hover.tga","GoodMap.tga"};
	tmpIconInfo2[11]={116,16,16,"NPC.tga","NPC_hover.tga","NPC.tga",10,"NPC.tga","NPC_hover.tga","NPC.tga"};
	tmpIconInfo2[12]={117,18,18,"FreepMap.tga","FreepMap_hover.tga","FreepMap.tga",nil,"FreepMap.tga","FreepMap_hover.tga","FreepMap.tga"};
	tmpIconInfo2[13]={118,18,18,"UnearnedMap.tga","UnearnedMap_hover.tga","UnearnedMap.tga",nil,"UnearnedMap.tga","UnearnedMap_hover.tga","UnearnedMap.tga"};
	tmpIconInfo2[14]={120,30,30,0x41005e9f,0x41005ea1,0x41005ea0,16,0x41005e9f,0x41005ea1,0x41005ea0}; -- auctioneer
	tmpIconInfo2[15]={121,32,32,"Barber.tga","Barber_hover.tga","Barber_icon.tga",17,"Barber.tga","Barber_hover.tga","Barber_icon.tga"};
	tmpIconInfo2[16]={122,30,30,0x41005e6a,0x41005e6c,0x41005e6b,18,0x41005e6a,0x41005e6c,0x41005e6b}; -- bard

	tmpIconInfo2[17]={123,30,30,0x410d4635,0x410d4637,0x410d4636,19,0x410d4635,0x410d4637,0x410d4636}; -- Camp Site (mini=0x410d4636 (15x15))
	tmpIconInfo2[18]={124,30,30,0x41005e76,0x41005e78,0x41005e77,20,0x41005e76,0x41005e78,0x41005e77}; -- Craft Facility

	tmpIconInfo2[19]={125,0,0,"placeholder.tga","placeholder.tga","placeholder.tga",nil,"placeholder.tga","placeholder.tga","placeholder.tga"}; -- ResourceNode NOT USED! This is separated into Ore, Wood, Scholar, etc
	tmpIconInfo2[20]={126,32,32,"CraftVendor.tga","CraftVendor_hover.tga","CraftVendor_icon.tga",21,"CraftVendor.tga","CraftVendor_hover.tga","CraftVendor_icon.tga"};
	tmpIconInfo2[21]={127,32,32,"FactionRep.tga","FactionRep_hover.tga","FactionRep_icon.tga",23,"FactionRep.tga","FactionRep_hover.tga","FactionRep_icon.tga"};
	tmpIconInfo2[22]={128,30,30,0x41005e88,0x41005e8a,0x41005e89,nil,0x41005e88,0x41005e8a,0x41005e89}; -- Fellow
	tmpIconInfo2[23]={129,0,0,"placeholder.tga","placeholder.tga","placeholder.tga",nil,"placeholder.tga","placeholder.tga","placeholder.tga"}; -- FellowLeader
	tmpIconInfo2[24]={130,30,30,0x41005e98,0x41005e9a,0x41005e99,nil,0x41005e98,0x41005e9a,0x41005e99}; -- FellowTrack
	tmpIconInfo2[25]={131,32,32,"Item-master.tga","Item-master_hover.tga","Item-master_icon.tga",24,"Item-master.tga","Item-master_hover.tga","Item-master_icon.tga"};
	tmpIconInfo2[26]={132,30,30,0x41005e94,0x41005e96,0x41005e95,25,0x41005e94,0x41005e96,0x41005e95};--Mailbox 
	tmpIconInfo2[27]={133,30,30,0x41005e52,0x41005e54,0x41005e53,26,0x41005e52,0x41005e54,0x41005e53}; -- milestone
	tmpIconInfo2[28]={134,0,0,"placeholder.tga","placeholder.tga","placeholder.tga",nil,"placeholder.tga","placeholder.tga","placeholder.tga"}; -- Pet
	tmpIconInfo2[29]={135,30,30,0x41005e4e,0x41005e50,0x41005e4f,nil,0x41005e4e,0x41005e50,0x41005e4f}; -- Quest NPC
	tmpIconInfo2[30]={136,0,0,"placeholder.tga","placeholder.tga","placeholder.tga",nil,"placeholder.tga","placeholder.tga","placeholder.tga"}; -- Quest Escort
	tmpIconInfo2[31]={137,30,30,0x41005e84,0x41005e86,0x41005e85,nil,0x41005e84,0x41005e86,0x41005e85}; -- Quest Failer
	tmpIconInfo2[32]={138,30,30,0x41005ea3,0x41005ea5,0x41005ea4,29,0x41005ea3,0x41005ea5,0x41005ea4}; -- reflecting pool
	tmpIconInfo2[33]={139,30,30,0x41005e56,0x41005e58,0x41005e57,30,0x41005e56,0x41005e58,0x41005e57}; -- Settlement
	tmpIconInfo2[34]={140,30,30,0x41005e72,0x41005e74,0x41005e73,31,0x41005e72,0x41005e74,0x41005e73}; -- stablemaster

	tmpIconInfo2[35]={141,32,32,"TownCrier.tga","TownCrier_hover.tga","TownCrier_icon.tga",34,"TownCrier.tga","TownCrier_hover.tga","TownCrier_icon.tga"};
	tmpIconInfo2[36]={142,30,30,0x41005e7f,0x41005e81,0x41005e80,nil,0x41005e7f,0x41005e81,0x41005e80}; -- Tracked Target
	tmpIconInfo2[37]={143,30,30,0x410d465c,0x410d465d,0x410d465a,35,0x410d465c,0x410d465d,0x410d465a}; -- Trader mini=0x410d465a (16x16)
	tmpIconInfo2[38]={144,30,30,0x41005e66,0x41005e68,0x41005e67,36,0x41005e66,0x41005e68,0x41005e67}; -- Trainer
	tmpIconInfo2[39]={145,30,30,0x41005e9d,0x41005e9d,0x41005e9e,38,0x41005e9d,0x41005e9d,0x41005e9e}; -- vaultkeeper doesn't have a highlighted icon with the other icons :(

	tmpIconInfo2[40]={146,30,30,0x41005e6e,0x41005e70,0x41005e6f,39,0x41005e6e,0x41005e70,0x41005e6f}; -- vendor
	tmpIconInfo2[41]={147,63,63,"MapConnector_blank.tga",0x410081a2,0x410081a2,nil,"MapConnector_blank.tga",0x410081a2,0x410081a2};
	tmpIconInfo2[42]={154,32,32,"SkirmishCamp.tga","SkirmishCamp_hover.tga","SkirmishCamp_icon.tga",40,"SkirmishCamp.tga","SkirmishCamp_hover.tga","SkirmishCamp_icon.tga"};
	tmpIconInfo2[43]={155,24,24,"OreNode.tga","OreNode_hover.tga","OreNode_icon.tga",11,"OreNode.tga","OreNode_hover.tga","OreNode_icon.tga"};
	tmpIconInfo2[44]={156,24,24,"WoodNode.tga","WoodNode_hover.tga","WoodNode_icon.tga",12,"WoodNode.tga","WoodNode_hover.tga","WoodNode_icon.tga"};
	tmpIconInfo2[45]={157,24,24,"ScholarNode.tga","ScholarNode_hover.tga","ScholarNode_icon.tga",13,"ScholarNode.tga","ScholarNode_hover.tga","ScholarNode_icon.tga"};
	tmpIconInfo2[46]={162,24,24,"Cook.tga","Cook_hover.tga","Cook_icon.tga",14,"Cook.tga","Cook_hover.tga","Cook_icon.tga"};
	tmpIconInfo2[47]={163,32,32,"MusterHorn.tga","MusterHorn_hover.tga","MusterHorn_icon.tga",27,"MusterHorn.tga","MusterHorn_hover.tga","MusterHorn_icon.tga"};
	tmpIconInfo2[48]={182,24,24,"Scholar.tga","Scholar_hover.tga","Scholar_icon.tga",15,"Scholar.tga","Scholar_hover.tga","Scholar_icon.tga"};
	tmpIconInfo2[49]={183,32,32,"Dungeon.tga","Dungeon_hover.tga","Dungeon_icon.tga",22,"Dungeon.tga","Dungeon_hover.tga","Dungeon_icon.tga"};
	tmpIconInfo2[50]={218,32,32,"Taskboard.tga","Taskboard_hover.tga","Taskboard_icon.tga",33,"Taskboard.tga","Taskboard_hover.tga","Taskboard_icon.tga"};
	tmpIconInfo2[51]={248,32,32,"StairUp.tga","StairUp_hover.tga","Stair_icon.tga",32,"StairUp.tga","StairUp_hover.tga","Stair_icon.tga"};
	tmpIconInfo2[52]={249,32,32,"StairDn.tga","StairDn_hover.tga","Stair_icon.tga",nil,"StairDn.tga","StairDn_hover.tga","Stair_icon.tga"};
	tmpIconInfo2[53]={272,30,30,0x41005e4e,0x41005e50,0x41005e4f,28,0x41005e4e,0x41005e50,0x41005e4f};
	tmpIconInfo2[54]={318,32,32,"Treasure.tga","Treasure_hover.tga","Treasure_icon.tga",37,"Treasure.tga","Treasure_hover.tga","Treasure_icon.tga"};
	tmpIconInfo2[55]={323,30,30,"CPOI.tga","CPOI_hover.tga","CPOI_icon.tga",8,"CPOI.tga","CPOI_hover.tga","CPOI_icon.tga"}; -- custom POI

-- now update the current default values
	for k,v in ipairs(tmpIconInfo2) do
		if tmpIconInfo[k]==nil then
			table.insert(tmpIconInfo,Table.Copy(v))
		elseif tmpIconInfo[k][8]==nil then
			tmpIconInfo[k]=Table.Copy(v)
		else
			-- overwrite all the defaults
			tmpIconInfo[1]=tmpIconInfo2[1]
			tmpIconInfo[7]=tmpIconInfo2[7]
			tmpIconInfo[8]=tmpIconInfo2[8]
			tmpIconInfo[9]=tmpIconInfo2[9]
			tmpIconInfo[10]=tmpIconInfo2[10]
		end
	end
	-- Map Data
	tmpMapInfo[1]={1,19,0x41008133,1024,768,63.6,1541,-63.5,-630,3,1,1,-10,-24.3,-22,-8.2,3}; -- ettenmoors
	tmpMapInfo[2]={2,20,0x41008139,1024,768, 1, 0, 1, 0,0,1,0,0,0,0,0,1}; -- Middle Earth coordinates are meaningless on this map :( different systems are in use in Eriador and Rhovanion
	tmpMapInfo[3]={3,21,0x41008138,1024,768,6.5,951,-6.5,186,2,1,1,28.6,-146.4,-89.4,11.1,2}; -- Eriador ,0x4101E0AE,0x4101E0A8,0x410EE3C8
	tmpMapInfo[4]={4,22,0x41008131,1024,768,35.03,1498,-34.95,514,3,1,1,14.7,-42.8,-7.3,-13.6,3}; -- Angmar
	tmpMapInfo[5]={5,23,0x41008136,1024,768,36.27,2377,-36.18,-640,3,1,1,-17.7,-65.6,-38.9,-37.4,3}; -- Bree-land
	tmpMapInfo[6]={6,24,0x41008135,1024,768,182.68,9280,-182.62,-4414,5,1,1,-24.2,-50.8,-28.4,-45.2,4}; -- Archet ,0x4101E0A1,0x4101e0ba
	tmpMapInfo[7]={7,25,0x4110a841,1024,768,213.13,12203,-213.06,-6370,5,1,1,-29.9,-57.3,-33.5,-52.5,4}; -- Barrow Downs North
	tmpMapInfo[8]={8,26,0x4110a842,1024,768,173.38,10012,-174.32,-5700,5,1,1,-32.7,-57.8,-37.1,-51.9,4}; -- Barrow Downs South
	tmpMapInfo[9]={9,27,0x41008134,1024,768,150,8194,-150,-4210,5,1,1,-28.1,-54.6,-33.2,-47.8,4}; -- Bree
	tmpMapInfo[10]={10,28,0x410d9a54,1024,768,189.44,9468,-191.75,-6519,5,1,1,-34,-50,-38,-44.6,4}; -- Bree-land Homesteads
	tmpMapInfo[11]={11,29,0x410e4ddd,1024,768,79.90,5206,-79.90,-2332,5,1,1,-29.2,-65.2,-38.8,-52.4,4}; -- The Old Forest
	tmpMapInfo[12]={12,30,0x411041a4,1024,768,32.99,1041,-32.92,-1767,3,1,1,-53.7,-31.6,-77,-.6,3}; -- Enedwaith ,nil,nil,0x411041ac
	tmpMapInfo[13]={13,31,0x4100812c,1024,768,38.7,4371,-38.66,-484,3,1,1,-12.6,-113,-32.4,-86.6,3}; -- Ered Luin
	tmpMapInfo[14]={14,32,0x410d9934,1024,768,182.78,17099,-182.72,-4437,13,1,1,-24.3,-93.6,-28.5,-88,4}; -- Falathlorn Homesteads
	tmpMapInfo[15]={15,33,0x4100812b,1024,768,128.70,13735,-128.75,-1442,13,1,1,-11.2,-106.8,-17.2,-98.8,4}; -- Thorin's Gate
	tmpMapInfo[16]={16,34,0x410d9a56,1024,768,192.45,21143,-192.65,-2531,13,1,1,-13.2,-109.9,-17.2,-104.6,4}; -- Thorin's Hall Homesteads
	tmpMapInfo[17]={17,35,0x410e8686,1024,768,33.8,802,-33.75,-1188,3,1,1,-35.2,-23.8,-58,6.5,3}; -- Eregion ,nil,0x410f5e2f,0x411012D8
	tmpMapInfo[18]={18,36,0x410e8694,1024,768,138.8,1237,-139.5,-6765,17,1,1,-48.5,-9,-54,-1.6,4}; -- The Walls of Moria
	tmpMapInfo[19]={19,37,0x4101f084,1024,768,33.7,2783,-33.71,-53,3,1,1,-1.6,-82.6,-24.4,-52.3,3}; -- Evendim
	tmpMapInfo[20]={20,38,0x410E6EAD,1024,768,134.61,9890,-134.56,-2085,19,1,1,-15.5,-73.5,-21.2,-65.9,4}; -- Annuminas
	tmpMapInfo[21]={21,39,0x410e3f46,1024,768,25.02,2320,-25.07,625,3,1,1,24.9,-92.8,-5.7,-51.9,3}; -- Forochel
	tmpMapInfo[22]={22,40,0x4110d5a5,1024,768,213.13,20545,-213.06,3069,3,1,1,14.4,-96.4,10.8,-91.6,3}; -- Frostbluff
	tmpMapInfo[23]={23,41,0x41008130,1024,768,43.72,1935,-43.83,-1148,3,1,1,-26.2,-44.3,-43.7,-20.9,3}; -- Lone-lands
	tmpMapInfo[24]={24,42,0x4100812f,1024,768,41.30,489,-41.24,-602,3,1,1,-14.6,-11.9,-33.2,12.9,3}; -- Misty Mountains
	tmpMapInfo[25]={25,43,0x41008132,1024,768,36.28,2190,-36.18,-47,3,1,1,-1.3,-60.4,-22.5,-32.2,3}; -- North Downs
	tmpMapInfo[26]={26,44,0x41008137,1024,768,48.48,3921,-48.24,-1104,3,1,1,-22.9,-80.9,-38.8,-59.8,3}; -- The Shire
	tmpMapInfo[27]={27,45,0x410d9a57,1024,768,182.68,14130,-178.37,-6171,26,1,1,-34.6,-77.4,-38.9,-71.8,4}; -- Shire Homesteads
	tmpMapInfo[28]={28,46,0x4100812e,1024,768,37.61,988,-37.41,-778,3,1,1,-20.8,-26.3,-41.3,.9,3}; -- Trollshaws
	tmpMapInfo[29]={29,47,0x4100812d,1024,768,105.46,982,-106.53,-2801,28,1,1,-26.3,-9.4,-33.5,.3,4,nil,nil,nil,{{-26.0,-7.2,1.2}},{{-7.2,-26.0,-33.2}},{{-31.6,-7.2,-3},{-33.2,-3,1.2}},{{1.2,-26,-33.2}}}; -- Rivendell
	tmpMapInfo[30]={30,48,0x411c2de4,1024,768,6.3067292645,802,-6.4516129032,288,2,1,2,42.4,-146.5,-86.9,24.6,2}; -- Rhovanion ,nil,nil,0x410f5e5a
	tmpMapInfo[31]={31,49,0x410e8707,1024,768,48.7,3995,-48.63,-223,30,1,2,-6.2,-80.92,-18.99,-62.13,3}; -- Lothlrien
	tmpMapInfo[32]={32,50,0x410e8706,1024,768,179.47,12568,-178.37,-2300,31,1,2,-12.9,-70,-17.2,-64.3,4}; -- Caras Galadhon
	tmpMapInfo[33]={33,51,0x41100DF2,1024,768,41.2,2618,-41.2,-200,30,1,2,-4.9,-63.6,-23.5,-38.8,3}; -- mirkwood
-- moria
	tmpMapInfo[34]={34,52,0x410e8708,1024,768,30,3653,-29.9,86,30,1,2,2.8,-121.8,-22.8,-87.7,3}; -- moria
	tmpMapInfo[35]={35,53,0x410e871d,1024,768,63.94,7289,-63.92,128,34,1,2,2,-114,-10,-98,4}; -- Durin's Way
	tmpMapInfo[36]={36,54,0x410e8716,1024,768,136.4,15286,-136.96,-1698,34,1,2,-12.4,-112.1,-18,-104.6,4}; -- Flaming Deeps
	tmpMapInfo[37]={37,55,0x410e8715,1024,768,132.86,13658,-132.24,-1401,34,1,2,-10.6,-102.8,-16.4,-95.1,4}; -- Foundations of Stone
	tmpMapInfo[38]={38,56,0x410e871a,1024,768,91.4,9612,-91.4,-365,34,1,2,-4,-105.2,-12.4,-94,4}; -- Nud Melek
	tmpMapInfo[39]={39,57,0x410e8718,1024,768,106.56,11632,-108.03,-1004,34,1,2,-9.3,-109.2,-16.4,-99.6,4}; -- Redhorn Lodes
	tmpMapInfo[40]={40,58,0x410e8e5a,1024,768,162.38,22967,-163.19,12060,34,3,2,73.9,-141.5,69.2,-135.2,4}; -- The Grand Stair
	tmpMapInfo[41]={41,59,0x410e871c,1024,768,141.8,16620,-141.8,-698,34,1,2,-4.9,-117.2,-10.3,-110,4}; -- The Great Delving
	tmpMapInfo[42]={42,60,0x410e8719,1024,768,142.08,16486,-142.04,-1221,34,1,2,-8.6,-116.1,-14,-108.9,4}; -- The Silvertine Lodes
	tmpMapInfo[43]={43,61,0x410e8717,1024,768,74.0566,8921,-73.9583,-835,34,1,2,-12.36,-117.56,-19,-109.07,4}; -- The Waterworks
	tmpMapInfo[44]={44,62,0x410e871b,1024,768,76.34,8700,-75.94,-296,34,1,2,-3.9,-114,-14,-100.6,4}; -- Zelem Melek
	tmpMapInfo[45]={45,63,0x410e871e,1024,768,134.61,15209,-134.56,2328,34,1,2,17.3,-113,11.6,-105.4,4}; -- Zirak Zigil
-- these are the first "interior" maps
	tmpMapInfo[46]={46,184,0x41005d2f,1600,1200,300,-13450,-300,23550,15,2,1,77.8,46.42,75.31,48.75,5}; -- Thorin's Hall main floor
	tmpMapInfo[47]={47,185,0x410d4163,1600,1200,300,-13450,-300,23550,15,2,1,77.1,47.08,76.59,48.06,5}; -- Thorin's Hall basement
	tmpMapInfo[48]={48,186,0x410d81c3,1600,1200,300,-15185,-300,-19395,1,2,1,-65.44,52.0,-67.85,54.53,4}; -- Delving of Fror

	tmpMapInfo[49]={49,187,0x41005c2f,800,600,1,0,1,0,5,3,1,0,0,0,0,4}; -- Breeland Brigand Cave
	tmpMapInfo[50]={50,188,0x41007dc5,800,600,600,-30310,-600,45403,15,3,1,75.4,50.97,74.97,51.41,5}; -- Rockbelly Pit
	tmpMapInfo[51]={51,189,0x41007dbe,1600,1200,803.7037037037,-41935,-806.0606060606,-4086,6,3,1,-5.46,52.54,-6.18,53.78,5}; -- Sprigley's Cellar actual
	tmpMapInfo[52]={52,190,0x41005C0D,800,600,597.5,-30229,-591.8918918919,45291,15,3,1,76.28,50.84,75.74,51.66,5}; -- Mirkstone Tunnels
	tmpMapInfo[53]={53,191,0x41005C1F,800,600,266.6666666667,-13009,-270.7317073171,21246,15,3,1,77.73,49.44,77.02,51.11,5}; -- Silver Deep
	tmpMapInfo[54]={54,192,0x41005C2D,1600,1200,400,-19806,-398.3739837398,32373,15,3,1,80.81,50.71,79,52.17,5}; -- Skorgrim's Tomb
	tmpMapInfo[55]={55,193,0x41110D27,800,600,1,0,1,0,19,3,1,0,0,0,0,4}; -- Annuminas: Haudh Valandur
	tmpMapInfo[56]={56,194,0x41110D29,800,600,1,0,1,0,19,3,1,0,0,0,0,4}; -- Annuminas: Haudh Erendur
	tmpMapInfo[57]={57,195,0x41110D2C,1600,1200,1,0,1,0,19,3,1,0,0,0,0,4}; -- Annuminas: Haudh Eldacar
	tmpMapInfo[58]={58,196,0x41110D2E,1600,1200,1,0,1,0,19,3,1,0,0,0,0,4}; -- Annuminas: Haudh Arantar
	tmpMapInfo[59]={59,197,0x4101fd4f,800,600,1,0,1,0,19,3,1,0,0,0,0,4}; -- Evendim: Gwindethrond
-- new RoI maps
	tmpMapInfo[60]={60,203,0x41119615,1024,768,31.2844,892,-31.3061,-2207,3,1,1,-70.5,-28.5,-95,4.2,3}; -- Dunlending ,nil,nil,0x41119612
	tmpMapInfo[61]={61,204,0x4111961d,1024,768,38.31461,1096,-38.1592,-2701,60,1,1,-70.8,-28.1,-90.9,-1.9,4}; -- Dunland ,nil,nil,0x41119622
	tmpMapInfo[62]={62,205,0x41116d55,1024,768,51.40704,1070,-51.4765,-4138,60,1,1,-80.4,-20.8,-94.4,-2.0,4}; -- Gap Of Rohan ,0x41116edc,0x41116edd,0x41116ee0
	tmpMapInfo[63]={63,206,0x41119607,1024,768,75.22059,715,-74.466,-5666,60,1,1,-76.1,-9.5,-86.0,3.8,4}; -- Nan Curunir ,nil,nil,0x4111960c
	tmpMapInfo[64]={64,207,0x41116EFE,1024,768,284.1667,5229,-284.074,-22413,61,1,1,-78.9,-18.4,-81.8,-14.8,5}; -- Galtrev ,nil,nil,0x41116f03
	tmpMapInfo[65]={65,208,0x41116f01,1024,768,132.8571,838,-132.241,-10090,63,1,1,-76.3,-6.3,-82.1,1.4,5}; -- Isengard ,nil,nil,0x41116f0c
-- Isengard Depths 0x4111923d
-- Ring of Isengard 0x41119257
	tmpMapInfo[66]={66,209,0x411195ff,1024,768,258.8745,24421.9,-256.585,13425.52,62,3,1,52.1,-93.7,49.6,-91.0,5}; -- Pit of Iron

-- the great river maps
	tmpMapInfo[67]={67,214,0x4111e1c0,1024,768,37.61029,2780,-37.598,-646,30,1,2,-19.0,-73.9,-37.6,-46.7,3}; -- the great river ,0x4111e1c1,0x4111e1c2
	tmpMapInfo[68]={68,215,0x41123f09,1024,768,352.7586,22965,-348.636,-8681,67,1,2,-24.9,-65.1,-27.1,-62.2,4}; -- stangard
-- Tal Methedras
	tmpMapInfo[69]={69,216,0x4111b941,1024,768,113.289,1635.8,-112.794,-8132,60,1,1,-72.7,-12.3,-77.7,-7.1,4}; -- Tal Methedras after
	tmpMapInfo[70]={70,217,0x4111b941,1024,768,113.289,1635.8,-112.794,-8132,60,1,1,-72.7,-12.3,-77.7,-7.1,4}; -- Tal Methedras before

	tmpMapInfo[71]={71,228,0x41129eb7,1024,768,23.9019,1853.4,-23.8941,-799.452,30,1,2,-33.5,-77.5,-65.6,-34.7,3}; -- east rohan ,0x41129eb3,0x41129eb1
	tmpMapInfo[72]={72,229,0x4112d1dd,1024,768,76.9173,6108.2,-77.4747,-2664.13,71,1,2,-34.4,-79.4,-44.3,-66.1,4}; -- eaves of fangorn ,0x4112fcd6,0x4112fcd7
	tmpMapInfo[73]={73,230,0x4112d1dc,1024,768,42.9832,2635.9,-43.0899,-1968.21,71,1,2,-45.7,-61.3,-63.5,-37.5,4}; -- east wall ,0x4112fccd,0x4112fccf
	tmpMapInfo[74]={74,231,0x4112d1e1,1024,768,49.1827,3655.3,-48.8535,-1899.3,71,1,2,-38.9,-74.3,-54.6,-53.5,4}; -- entwash vale ,0x4112fcdb,0x4112fcdc
	tmpMapInfo[75]={75,232,0x4112d1e0,1024,768,47.1429,3159,-47.3457,-1982.78,71,1,2,-41.8,-67.0,-58.1,-45.3,4}; -- Norcrofts ,0x4112fcdf,0x4112fce1
	tmpMapInfo[76]={76,233,0x4112d1df,1024,768,51.6667,3612.5,-51.8243,-2714.59,71,1,2,-52.4,-69.9,-67.2,-50.1,4}; -- sutcrofts ,0x4112fce5,0x4112fce6
	tmpMapInfo[77]={77,234,0x4112d1de,1024,768,41.25,2649.3,-41.016,-1233.58,71,1,2,-30.1,-64.2,-48.8,-39.4,4}; -- The Wold ,0x4112fceb,0x4112fcec

-- RoR cities
	tmpMapInfo[78]={78,235,0x41132e10,1024,768,249.1525,13594,-250.185,-9457,77,1,2,-37.9,-54.6,-40.9,-50.5,5}; -- Harwick ,0x41132e11,0x41132e0f
	tmpMapInfo[79]={79,236,0x41132e57,1024,768,249.1409,15938,-249.791,-14803,76,1,2,-59.3,-64.0,-62.4,-59.9,5}; -- Snowbourn ,0x41132e59,0x41132e5b

	tmpMapInfo[80]={80,237,"GaranStuff/MoorMap/Maps/Cliving.jpg",1024,768,249.6104,14575,-250.181,-10517.6,75,1,2,-42.1,-58.4,-45.2,-54.3,5}; -- Cliving
	tmpMapInfo[81]={81,244,"GaranStuff/MoorMap/Maps/Eaworth.jpg",512,384,248.7179,16132,-250.877,-11765.35,74,1,2,-46.9,-64.9,-48.5,-62.9,5}; -- Eaworth
-- more interiors
	tmpMapInfo[82]={82,242,0x4112881f,1600,1200,601.8348623853,-31801,-593.75,13184,74,3,2,21.62,53.46,20.68,54.86,5}; -- Byrgenstow upper
	tmpMapInfo[83]={83,243,0x4112881e,1600,1200,598.1481481481,-31603,-597.6744186047,13269,74,3,2,21.62,53.46,20.68,54.86,5}; -- Byrgenstow lower

	tmpMapInfo[84]={84,245,0x4112a9de,800,600,401.0416666667,58308,-398.5263157895,-7498,76,3,2,-18.6,-145.7,-20.6,-143.2,5}; -- Langraf 0x4112a9de (800,600)
	tmpMapInfo[85]={85,246,0x4112acb9,1600,1200,596.1038961039,-31660,-598.6394557823,35318,75,3,2,58.76,53.74,57.22,54.87,5}; -- Ost Magol lower 0x4112acb9 (1600,1200)
	tmpMapInfo[86]={86,247,0x4112acba,1600,1200,602.6666666667,-32019,-600.6802721088,35435,75,3,2,58.76,53.74,57.22,54.87,5}; -- Ost Magol upper 0x4112acba (1600,1200)
	tmpMapInfo[87]={87,250,0x4112d640,1600,1200,603.2,-30376,-596.7479674797,32265,74,3,2,53.9,50.7,52.3,52.3,5}; -- The Living Deep 0x4112d640 (1600,1200)
	tmpMapInfo[88]={88,251,0x4112a39f,800,600,596.6176470588,-31521,-601.7948717949,36063,77,3,2,59.9,53,58.9,53.9,5}; -- Gerngarth 1 0x4112a39f (800,600)
	tmpMapInfo[89]={89,252,0x4112a3a0,800,600,597.9411764706,-31592,-603.3333333333,36127,77,3,2,59.9,53,58.9,53.9,5}; -- Gerngarth 2 0x4112a3a0 (800,600)
	tmpMapInfo[90]={90,253,0x41129d3d,1600,1200,601.6260162602,-30997,-598.4962406015,37234,76,3,2,62,51.9,60.3,53.6,5}; -- Isengraf 0x41129d3d (1600,1200)
	tmpMapInfo[91]={91,254,0x4112884f,1600,1200,600,-32262,-600,14638,74,3,2,23.4,54.46,22.81,55.39,5}; -- Wyrmdelf 1 0x4112884f (1600,1200)
	tmpMapInfo[92]={92,255,0x4112884e,1600,1200,598.1308411215,-32160,-605.6338028169,14771,74,3,2,24.16,54.51,23.17,55.76,5}; -- Wyrmdelf 2 0x4112884e (1600,1200)
	tmpMapInfo[93]={93,256,0x4112a9af,800,600,297.9166666667,-15945,-298.9795918367,18625,75,3,2,61.82,54.34,60.79,55.38,5}; -- Dwergfant 0x4112a9af (800,600)
	tmpMapInfo[94]={94,257,0x4112de9c,1600,1200,301.4814814815,-14078,-300,9211,75,3,2,29.84,48.46,27.6,50.08,5}; -- The Ancient Tomb 0x4112de9c (1600,1200)
	tmpMapInfo[95]={95,258,0x4112a585,1600,1200,591.6666666667,-30503,-598.8636363636,35753,77,3,2,59.21,52.53,58.14,53.3,5}; -- Digelon Lower 0x4112a585 (1600,1200)
	tmpMapInfo[96]={96,259,0x4112a584,1600,1200,602.2727272727,-31156,-600,35575,77,3,2,58.91,52.5,57.74,53.59,5}; -- Digelon Middle 0x4112a584 (1600,1200)
	tmpMapInfo[97]={97,260,0x4112a586,800,600,606.3333333333,-31768,-607.6086956522,35692,77,3,2,58.55,52.78,57.92,53.33,5}; -- Digelon Upper 0x4112a586 (800,600)
	tmpMapInfo[98]={98,261,0x4112ab42,1600,1200,300.4608294931,44259,-301.0101010101,-4643,76,3,2,-16.51,-146.04,-18.9,-143.49,5}; -- The Creeping Wood 0x4112ab42 (1600,1200)
-- goblin-town
	tmpMapInfo[99]={99,262,0x410d9810,1600,1200,298.8679245283,-15704,-301.5384615385,-20307,24,3,1,-67.58,53.46,-70.87,56.87,4}; -- Goblintown tunnels south 0x410d9810 (1600,1200)
	tmpMapInfo[100]={100,263,0x410d9812,1600,1200,299.0147783251,-15742,-300,-19704,24,3,1,-66.5,54.11,-68.85,56.54,4}; -- Goblintown tunnels central 0x410d9812 (1600,1200)
	tmpMapInfo[101]={101,264,0x410d9811,1600,1200,299.5744680851,-15953,-300.9561752988,-19333,24,3,1,-64.7,54.93,-67.65,57.03,4}; -- Goblintown tunnels north 0x410d9811 (1600,1200)
	tmpMapInfo[102]={102,265,0x410d9813,800,600,304.4444444444,-16294,-297.3846153846,-19011,24,3,1,-64.56,54.47,-65.31,55.19,4}; -- Goblintown Slave Pens 0x410d9813 (800,600)
	tmpMapInfo[103]={103,266,0x410d980d,800,600,302.8571428571,-16100,-298.8461538462,-18855,24,3,1,-63.47,53.87,-64.66,54.98,4}; -- Goblintown War Steadings 0x410d980d (800,600)
	tmpMapInfo[104]={104,267,0x410d980f,800,600,297.397260274,-15941,-299.298245614,-19603,24,3,1,-65.81,54.4,-67.16,55.46,4}; -- Goblintown Thundergrot 0x410d980f (800,600)
	tmpMapInfo[105]={105,268,0x410d9814,800,600,299.21875,-16180,-302.6153846154,-18931,24,3,1,-63.22,54.63,-63.97,56.17,4}; -- Gollums Cave 0x410d9814 (800,600)
	tmpMapInfo[106]={106,269,0x410d980e,800,600,300.9090909091,-15951,-298.7878787879,-18514,24,3,1,-62.45,53.65,-63.57,54.83,4}; -- Goblintown Throne Room 0x410d980e (800,600)
	tmpMapInfo[107]={107,270,0x411295b6,800,600,604.4444444444,-31870,-596.2962962963,37748,76,3,2,62.97,52.98,62.63,53.58,5}; -- Parphad Upper 0x411295b6 (800,600)
	tmpMapInfo[108]={108,271,0x411295b7,800,600,602.5210084034,-31767,-595.5,37697,76,3,2,63.12,52.76,62.47,54,5}; -- Parphad Lower 0x411295b7 (800,600)

-- more Moria interiors
	tmpMapInfo[109]={109,274,0x410ea77c,800,600,601.5873015873,-33347,-592.5925925926,31842,35,3,2,53.37,55.7,53.08,56.46,5}; -- The Peaceful Path
	tmpMapInfo[110]={110,275,0x410ea77d,1600,1200,598.8235294118,-32695,-597.2727272727,33366,35,3,2,55.57,55.28,54.22,56.67,5}; -- Ghar-khafush
	tmpMapInfo[111]={111,276,0x410f4c06,800,600,297.6635514019,-16340,-301.9230769231,7998,35,3,2,26.05,55.64,24.92,56.83,5}; -- Buzun-ghar
-- RoR Wildermore
	tmpMapInfo[112]={112,277,0x411375af,1024,768,38.7719,3009.2,-38.6233,-1044.19,71,1,2,-27.1,-77.7,-45.4,-53.9,4}; -- Wildermore ,0x411375a9,0x411375ad
	tmpMapInfo[113]={113,278,0x411379ff,1024,768,334.7517,20914,-334.9282297,-12542,112,1,2,-37.5,-62.5,-39.8,-59.5,5}; -- Forlaw ,0x41137a01,0x411379fd
-- RoR Westemnet
	tmpMapInfo[114]={114,287,0x4113C325,1024,768,19.40299,1892,-19.3191,-760,30,1,2,-39.3,-97.6,-79.0,-44.8,3}; -- west rohan,0x41142C46,0x41142C4b
	tmpMapInfo[115]={115,288,0x4113C31F,1024,768,30.91317,2678,-30.9563,-1575,114,1,2,-50.9,-86.6,-75.6,-53.6,4}; --kingstead ,0x41142C3D,0x41142C4F
	tmpMapInfo[116]={116,289,0x4113C320,1024,768,64.03197,4997,-63.6986,-2646,114,1,2,-41.6,-78.1,-53.5,-62.1,4}; -- broadacres ,0x41142C4E,0x41142C3F
	tmpMapInfo[117]={117,290,0x4113C321,1024,768,45.08133,3202,-45.3157,-2719,114,1,2,-60.0,-71.0,-77.0,-48.4,4}; -- eastfold ,0x41142C42,0x41142C3C
	tmpMapInfo[118]={118,291,0x4113C322,1024,768,50.08547,4464,-49.842,-2196,114,1,2,-44.1,-89.2,-59.4,-68.7,4}; -- stonedeans ,0x41142C51,0x41142C3E
	tmpMapInfo[119]={119,292,0x4113C323,1024,768,119.3396,11134,-118.373,-7141,114,1,2,-60.3,-93.3,-66.8,-84.7,4}; -- helm's deep ,0x41142C38,0x41142C4D
	tmpMapInfo[120]={120,293,0x4113C324,1024,768,45.26823,4306,-45.1091,-2366,114,1,2,-52.5,-95.2,-69.4,-72.5,4}; -- westfold ,0x41142C52,0x41142C55
	tmpMapInfo[121]={121,294,0x4113C31E,1024,768,129.0462,9921,-129.122,-7510,115,1,2,-58.2,-76.9,-64.1,-69.0,5}; -- edoras ,0x41142C3A,0x41142C54
	tmpMapInfo[122]={122,296,0x4114BEAA,1024,768,103.2885,8944,-103.14,-3846,114,1,2,-37.29,-86.6,-44.73,-76.69,4}; -- entwood
	tmpMapInfo[123]={123,297,0x4114E11C,1024,768,73.71865,7142,-73.7095,-3134,114,1,2,-42.6,-96.9,-53,-83.1,4}; -- isengard (flooded)
-- West Gondor
	tmpMapInfo[124]={124,304,0x41154336,1024,768,9.4941956882,936,-9.9729241877,-234,2,1,3,-52.7,-86.6,-81.3,-49,2}; -- Gondor
	tmpMapInfo[125]={125,298,0x411538df,1024,768,23.788443616,2144,-23.7451050196,-1200,124,1,3,-50.6,-90.2,-82.9,-47.2,3}; -- west gondor
	tmpMapInfo[126]={126,299,0x41154eed,1024,768,37.6321353066,3128,-37.5598086124,-1916,125,1,3,-51.1,-83.2,-71.1,-56.2,4}; -- blackroot vale
	tmpMapInfo[127]={127,300,0x41154eeb,1024,768,37.4069478908,3155,-37.5686813187,-2515,125,1,3,-67,-84.3,-87.4,-57.3,4}; -- havens of belfalas
	tmpMapInfo[128]={128,301,0x41154e05,1024,768,158.6330935252,11805,-158.6283185841,-11483,127,1,3,-72.4,-74.5,-77.2,-68,5}; -- dol amroth
	tmpMapInfo[129]={129,302,0x41154eec,1024,768,46.9821757837,3335,-47.0261437908,-2742,125,1,3,-58.4,-71,-74.6,-49.3,4}; -- lamedon
	tmpMapInfo[130]={130,303,0x41154c34,1024,768,160,12526,-160.2409638554,-6735,125,1,3,-42.1,-78.3,-46.9,-71.9,4}; -- PotD

	tmpMapInfo[131]={131,305,0x41158979,1024,768,110.2013422819,2147,-109.8666666667,-2750,124,1,3,-25.0,-19.5,-32.0,-10.2,3};

	tmpMapInfo[132]={132,306,0x4115b943,1024,768,31.2684365782,1864,-31.4232902033,-2095,124,1,3,-66.6,-59.7,-91.1,-26.9,3}; -- Cental gondor
	tmpMapInfo[133]={133,307,0x4115b93f,1024,768,81.1240721103,4626,-81.4814814815,-5582,132,1,3,-68.5,-57.0,-77.9,-44.4,4}; -- Ringlo
	tmpMapInfo[134]={134,308,0x4115b944,1024,768,56.8965517241,2741,-56.8325791855,-4256,132,1,3,-74.9,-48.2,-88.4,-30.2,4}; -- Lebennin
	tmpMapInfo[135]={135,309,0x4115b93c,1024,768,147.6525821596,5538,-147.9797979798,-12107,134,1,3,-81.8,-37.5,-87.0,-30.6,5}; -- Pelargir
	tmpMapInfo[136]={136,310,0x4115b945,1024,768,60.0821167883,3553,-60.1128880527,-4525,132,1,3,-75.3,-59.2,-88.0,-42.1,4}; -- Dor-en-ernil
	tmpMapInfo[137]={137,311,0x4115b98b,1024,768,192.6267281106,10913,-192.5,6850,30,1,2,35.6,-56.7,31.6,-51.3,3}; -- Grimbeorn's House
-- eastern gondor
	tmpMapInfo[138]={138,312,0x4115ee35,1024,768,27.4534553487,999,-27.533632287,-1628,124,1,3,-59.2,-36.4,-87.0,0.4,3}; -- Eastern Gondor
	tmpMapInfo[139]={139,313,0x4115ee38,1024,768,67.6829268293,2526,-67.5175175175,-4987,138,1,3,-73.9,-37.4,-85.2,-22.2,4}; -- Upper Lebennin
	tmpMapInfo[140]={140,314,0x4115ee3a,1024,768,38.6494252874,1024,-38.8235294118,-2341,138,1,3,-60.3,-26.5,-80.1,-0.1,4}; -- South Ithilien
	tmpMapInfo[141]={141,315,0x4115ee3c,1024,768,59.9740090968,1968,-60.0481347774,-4176,138,1,3,-69.6,-32.8,-82.4,-15.8,4}; -- Lossarnach
	tmpMapInfo[142]={142,316,0x4115ee41,1024,768,106.0877192982,1431,-106.4220183486,-6252,140,1,3,-58.7,-13.5,-66.0,-3.9,5}; -- Osgiliath
	tmpMapInfo[143]={143,317,0x41162479,1024,768,106.0877192982,1431,-106.4220183486,-6252,140,1,3,-58.7,-13.5,-66.0,-3.9,5}; -- Osgiliath (PvMP)
	tmpMapInfo[144]={144,319,0x411656ee,1024,768,43.7535014006,1150,-43.75,-1964,147,1,3,-44.9,-23.5,-62.2,-6.5,4}; -- Talath Anor
	tmpMapInfo[145]={145,320,0x411656ef,1024,768,112.6033057851,2712,-112.8846153846,-7017,146,1,3,-62.5,-21.2,-68.74,-15.6,5}; -- Minas Tirith
	tmpMapInfo[146]={146,321,0x411656f0,1024,768,51.3146734521,1426,-51.4705882353,-3002,147,1,3,-62.9,-21.0,-68.0,-16.2,4}; -- Pelennor
	tmpMapInfo[147]={147,322,0x411656f1,1024,768,26.2916188289,891,-26.2782401902,-1172,124,1,3,-44.6,-24.3,-72.6,-7.0,3}; -- Old Anorien

	tmpMapInfo[148]={148,334,0x4116af91,1024,768,29.9934832193,1511,-29.9574468085,-972,124,1,3,-32.4,-50.3,-53.8,-16.3,3}; -- Far Anorien
	tmpMapInfo[149]={149,335,0x4116af8b,1024,768,41.2196356275,2112,-41.1783644559,-1310,148,1,3,-31.8,-51.2,-49.5,-26.4,4}; -- Beacon Hills
	tmpMapInfo[150]={150,336,0x4116af90,1024,768,48.7486965589,1651,-48.7216946676,-2071,148,1,3,-42.5,-33.8,-58.2,-12.9,4}; -- Taur Druadan

--old	tmpMapInfo[151]={151,341,0x411a42e6,1024,768, 37.9381443299,2991,-37.9754601227,-2904,125,1,3, -80.6,-78.7,-95.5,-52.1,4}; -- Cape of Belfalas
	tmpMapInfo[151]={151,341,0x411aef51,1024,768, 37.9381443299,2991,-37.9754601227,-2904,125,1,3, -80.6,-78.7,-95.5,-52.1,4}; -- Cape of Belfalas new
--	tmpMapInfo[151]={151,341,0x411aef52,1024,768, 37.9381443299,2991,-37.9754601227,-2904,125,1,3, -80.6,-78.7,-95.5,-52.1,4}; -- Cape of Belfalas housing
	tmpMapInfo[152]={152,338,0x411a4333,1024,768, 11.6480446927,231,-11.3679245283,-327,2,1,4, -13.4,-19.9,-110,127.2,2}; -- Mordor
	tmpMapInfo[153]={153,339,0x411a42e8,1024,768, 41.5248691099,1172,-41.6829745597,-2273,154,1,4, -55.1,-24.1,-72.5,-4.3,5}; -- Pelennor after battle
	tmpMapInfo[154]={154,340,0x411a42e7,1024,768, 27.7462792346,793,-27.5147928994,-1086,155,1,4, -39.7,-25.5,-67.1,3.2,4}; -- North Ithilien
	tmpMapInfo[155]={155,337,0x411a4436,1024,768, 23.7138263666,824,-23.8176314794,-945,152,1,4, -39.7,-26.7,-71.7,3.2,3}; -- March of the king
	tmpMapInfo[156]={156,342,0x411a42e5,1024,768, 136.3287250384,1798,-136.5778688525,-8132,153,1,4, -60,-12.3,-65,-6,6}; -- Osgiliath after battle
	tmpMapInfo[157]={157,344,0x4119389d,1024,768, 112.6033057851,2712,-112.8846153846,-7017,153,1,4,-62.5,-21.2,-68.74,-15.6,6}; -- Minas Tirith after battle
	tmpMapInfo[158]={158,343,0x41193988,1024,768, 0,0,0,0,155,3,4, -0,-0,0,0,4}; -- Throne of the dread terror ? instance?
	tmpMapInfo[159]={159,346,0x411ad8a9,1024,768, 49.9066583696,850,-49.9230769231,-1304,152,1,4, -26.2,-17.1,-41.5,3.4,3}; -- Wastes
	tmpMapInfo[160]={160,347,0x411ad936,1024,768, 0,0,0,0,159,3,4, -0,-0,0,0,4}; -- Battle of the Black Gate ? instance?
	tmpMapInfo[161]={161,360,0x411b84d4,1024,768, 22.5319006044,133,-22.5579470199,-798,152,1,4, -37.1,-3.9,-67.6,36,3}; -- Plateau of Gorgoroth
	tmpMapInfo[162]={162,361,0x411bca58,1024,768, 0,0,0,0,161,3,4, -0,-0,0,0,4}; -- Morannon war of the last alliance instance
	tmpMapInfo[163]={163,362,0x411b9591,1024,768, 62.4282198523,269,-62.5754527163,-2299,161,1,4, -37.2,-3.7,-48.6,10,4}; -- Udun
	tmpMapInfo[164]={164,363,0x411b958e,1024,768, 35.0233426704,226,-35.039817975,-1578,161,1,4, -45.4,-.7,-65.8,19.5,4}; -- Lhingris
	tmpMapInfo[165]={165,364,0x411b9590,1024,768, 42.5565491846,-287,-42.5475599669,-2039,161,1,4, -52,9,-65.2,29.9,4}; -- Talath Urui
	tmpMapInfo[166]={166,365,0x411b958c,1024,768, 47.5978647687,-870,-47.5425330813,-1992,161,1,4, -45.1,23.7,-57.5,38,4}; -- Agarnaith
	tmpMapInfo[167]={167,366,0x411b958d,1024,768, 43.8020578148,-262,-43.797856049,-1626,161,1,4, -42.1,6.5,-52.8,27.3,4}; -- Dor Amarth
	tmpMapInfo[168]={168,367,0x411b958f,1024,768, 62.490508732,-692,-62.5809935205,-2850,161,1,4, -46.5,11.9,-57.1,26.5,4}; -- Orodruin
	tmpMapInfo[169]={169,368,0x411bbfd1,1024,768, 169.7211155378,-1892,-168.8811188811,3290,165,1,4, 18.7,11.6,15.3,16.5,5}; -- Nargroth
	tmpMapInfo[170]={170,369,0x411bbfd0,1024,768, 0,0,0,0,168,1,4, -0,-0,0,0,5}; -- Sammath
	tmpMapInfo[171]={171,370,0x411c2de2,1024,768,23.8258317025,1348,-23.8938053097,892,30,1,2,35.1,-74.9,8.4,50.1,3}; -- North Mirkwood
	tmpMapInfo[172]={172,371,0x411c2de1,1024,768,191.8644067797,24755,-191.3725490196,9571,171,1,2,50,-129,46,-123.7,4}; -- Felegoth
	tmpMapInfo[173]={173,372,0x411bc61b,3200,2400,609.5238095238,-30997,-601.7857142857,9109,181,3,4,15.1,50.8,11.1,56,5}; -- Hall Under the Mountain
	tmpMapInfo[174]={174,373,0x411c3a74,1024,768,142.0833333333,2898,-142.037037037,-1648,33,1,2,-11.6,-20.4,-17,-13.2,4}; -- Dol Guldur (Razed)
	tmpMapInfo[175]={175,374,"GaranStuff/MoorMap/Maps/Dale.jpg",1024,768,373.8805970149,10051,-376.3440860215,9578,171,1,2,25.34,-26.85,23.48,-24.17,4}; -- Dale
	tmpMapInfo[176]={176,375,"GaranStuff/MoorMap/Maps/Laketown.jpg",1024,768,498.8023952096,13985,-498.1651376147,8978,171,1,2,17.95,-27.91,16.86,-26.24,4}; -- Laketown
	tmpMapInfo[177]={177,376,0x411c8da9,1024,768,40,2285,-40.0894187779,1858,30,1,2,45.6,-56.7,28.3,-32.5,3}; -- ered mithrin
	tmpMapInfo[178]={178,377,0x411cd4b8,1024,768,46.2332301342,1090,-46.3096960926,1545,30,1,2,32.5,-23.1,17.4,-2.1,3}; -- iron hills
	tmpMapInfo[179]={179,378,0x411ce4fc,1024,768,192.0634920635,26633,-193.2735426009,5020,177,1,2,25.33,-137.57,22.45,-134.31,4}; -- thikil-gundu
	tmpMapInfo[180]={180,379,0x411ce735,1024,768,192.2330097087,26726,-194,6435,177,1,2,32.9,-138,29.5,-135.88,4}; -- glimmerdeep
	tmpMapInfo[181]={181,380,0x411ce74f,1024,768,191.2280701754,26388,-191.4027149321,3140,171,1,2,15.7,-137.6,12.8,-133.4,4}; -- erebor
	tmpMapInfo[182]={182,381,0x411c5f05,2400,1800,801.0101010101,-41447,-794,39228,178,3,2,48.98,52.54,47.94,54.21,4}; -- jarnfast
	tmpMapInfo[183]={183,382,0x411d2eba,1024,768,0,0,0,0,177,1,2,0,0,0,0,4}; -- the anvil of winterstith raid instance
	tmpMapInfo[184]={184,383,0x411c7d9d,1600,1200,289.6551724138,-14148,-312,18197,177,2,2,56.94,51.39,56.2,51.99,4}; -- stormwall
	tmpMapInfo[185]={185,384,0x411c8712,2400,1800,790.6976744186,-39127,-802.7777777778,44957,184,3,2,55.8,50.07,53.91,51.94,5}; -- Caverns of Thrumfall
	tmpMapInfo[186]={186,385,0x41125525,800,600,670.5882352941,-34446,-602.2727272727,11901,43,3,2,19.76,51.36,18.76,52.55,5}; -- Moria Hulwul-nefekh
	tmpMapInfo[187]={187,386,0x410f5deb,800,600,816.6666666667,-45615,-804,50971,35,3,2,63.39,55.85,62.65,56.82,5}; -- Moria Chamber of Command
	tmpMapInfo[188]={188,387,0x4112b2e6,1600,1200,600,-32068,-598.9010989011,33460,74,3,2,55.42,54.42,54.3,55.07,5}; -- Haycliff 1
	tmpMapInfo[189]={189,388,0x4112b2e8,1600,1200,594.5945945946,-31774,-600,33404,74,3,2,55.23,54.49,54.09,54.96,5}; -- Haycliff 2
	tmpMapInfo[190]={190,389,0x4112b2e7,800,600,591.3043478261,-31992,-598.5074626866,33023,74,3,2,55.04,54.49,54.3,54.96,5}; -- Haycliff 3
	tmpMapInfo[191]={191,391,0x410ea791,1600,1200,601.2048192771,-33011,-597.2602739726,18304,38,3,2,30.4,55.38,28.87,57.09,5}; -- Moria Mamalsul
	tmpMapInfo[192]={192,392,0x410ea77f,1600,1200,299.2084432718,-15543,-299.3377483444,18027,43,3,2,59.12,52.61,57.31,56.62,5}; -- Moria Drowned Treasury
	tmpMapInfo[193]={193,393,0x410ea782,1600,1200,605.8823529412,-33175,-595.0617283951,36759,43,3,2,61.27,55.52,60.25,56.61,5}; -- Moria Deep-way
	tmpMapInfo[194]={194,394,0x410ea781,1600,1200,598.3606557377,-32903,-597.9797979798,36266,43,3,2,60.25,55.64,59.03,57.01,5}; -- Moria Way of Smiths
	tmpMapInfo[195]={195,395,0x410ea77b,800,600,600,-33235,-603.3333333333,31408,37,3,2,51.85,55.81,51.25,56.31,5}; -- Moria Gwathrendath
	tmpMapInfo[196]={196,396,0x410ea775,800,600,298.4615384615,-16544,-297.2222222222,13684,37,3,2,45.43,56.36,44.62,57.17,5}; -- Moria Azanarukar upper i24 max oz ? min oz -54.49
	tmpMapInfo[197]={197,397,0x410ea776,1600,1200,610.8108108108,-33876,-603.5087719298,27654,37,3,2,45.31,56.47,44.31,57.06,5}; -- Moria Azanarukar mid i24 max oz -54.50 min oz -84.49
	tmpMapInfo[198]={198,398,0x410ea777,1600,1200,590.9090909091,-32689,-598.5294117647,27582,37,3,2,45.83,56.36,44.32,56.98,5}; -- Moria Azanarukar lower i24 max oz -84.5 min oz -?
	tmpMapInfo[199]={199,399,0x411da4a0,1024,768,24.9741735537,2030,-25.0338294993,458,30,1,2,17.05,-71.97,-10.9,-46.45,3}; -- Vales of Anduin
	tmpMapInfo[200]={200,400,0x411d9e32,800,600,597.2222222222,-31406,-614.8148148148,33860,199,3,2,54.86,53.02,54.32,53.52,4}; -- Avabarg
	tmpMapInfo[201]={201,402,0x411da1dd,800,600,597.0588235294,-30401,-597.8723404255,23656,199,3,2,39.3,51.34,38.78,51.76,4}; -- Tum Melen

	PatchDataSave( Turbine.DataScope.Account, "MM_IconInfo", tmpIconInfo);
	PatchDataSave( Turbine.DataScope.Account, "MM_MapInfo", tmpMapInfo);
end
